@@ -3,9 +3,9 @@
  *
  * Implementation of the Domain-Free Mandatory Access Control.
  *
- * Copyright (C) 2005-2008  NTT DATA CORPORATION
+ * Copyright (C) 2005-2009  NTT DATA CORPORATION
  *
- * Version: 1.6.4   2008/09/03
+ * Version: 1.6.8   2009/05/28
  *
  * This file is applicable to both 2.4.30 and 2.6.11 and later.
  * See README.ccs for ChangeLog.
@@ -32,7 +32,7 @@
 #endif
 
 /**
- * check_conceal_mount - Check whether this mount request shadows existing mounts.
+ * ccs_check_conceal_mount - Check whether this mount request shadows existing mounts.
  *
  * @path:   Pointer to "struct path" (for 2.6.27 and later).
  *          Pointer to "struct nameidata" (for 2.6.26 and earlier).
@@ -41,8 +41,9 @@
  *
  * Returns true if @vfsmnt is parent directory compared to @nd, false otherwise.
  */
-static bool check_conceal_mount(struct PATH_or_NAMEIDATA *path,
-				struct vfsmount *vfsmnt, struct dentry *dentry)
+static bool ccs_check_conceal_mount(struct PATH_or_NAMEIDATA *path,
+				    struct vfsmount *vfsmnt,
+				    struct dentry *dentry)
 {
 	/***** CRITICAL SECTION START *****/
 	while (1) {
@@ -69,19 +70,20 @@ static bool check_conceal_mount(struct PATH_or_NAMEIDATA *path,
 }
 
 /**
- * print_error - Print error message.
+ * ccs_print_error - Print error message.
  *
+ * @r:    Pointer to "struct ccs_request_info".
  * @path: Pointer to "struct path" (for 2.6.27 and later).
  *        Pointer to "struct nameidata" (for 2.6.26 and earlier).
- * @mode: Access control mode.
  *
- * Returns 0 if @mode is not enforcing or permitted by the administrator's
+ * Returns 0 if @r->mode is not enforcing or permitted by the administrator's
  * decision, negative value otherwise.
  */
-static int print_error(struct PATH_or_NAMEIDATA *path, const u8 mode)
+static int ccs_print_error(struct ccs_request_info *r,
+			   struct PATH_or_NAMEIDATA *path)
 {
 	int error;
-	const bool is_enforce = (mode == 3);
+	const bool is_enforce = (r->mode == 3);
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 25) && LINUX_VERSION_CODE <= KERNEL_VERSION(2, 6, 26)
 	const char *dir = ccs_realpath_from_dentry(path->path.dentry,
 						   path->path.mnt);
@@ -91,10 +93,9 @@ static int print_error(struct PATH_or_NAMEIDATA *path, const u8 mode)
 	const char *exename = ccs_get_exe();
 	printk(KERN_WARNING "SAKURA-%s: mount %s (pid=%d:exe=%s): "
 	       "Permission denied.\n", ccs_get_msg(is_enforce), dir,
-	       current->pid, exename);
+	       (pid_t) sys_getpid(), exename);
 	if (is_enforce)
-		error = ccs_check_supervisor(NULL,
-					     "# %s is requesting\n"
+		error = ccs_check_supervisor(r, "# %s is requesting\n"
 					     "mount on %s\n", exename, dir);
 	else
 		error = 0;
@@ -112,9 +113,9 @@ static int print_error(struct PATH_or_NAMEIDATA *path, const u8 mode)
  */
 int ccs_may_mount(struct PATH_or_NAMEIDATA *path)
 {
+	struct ccs_request_info r;
 	struct list_head *p;
 	bool flag = false;
-	const u8 mode = ccs_check_flags(CCS_SAKURA_DENY_CONCEAL_MOUNT);
 #if LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 19)
 	struct namespace *namespace = current->namespace;
 #elif LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 20)
@@ -122,10 +123,14 @@ int ccs_may_mount(struct PATH_or_NAMEIDATA *path)
 #else
 	struct mnt_namespace *namespace = current->nsproxy->mnt_ns;
 #endif
-	if (!mode)
+	if (!ccs_can_sleep())
+		return 0;
+	ccs_init_request_info(&r, NULL, CCS_DENY_CONCEAL_MOUNT);
+	if (!r.mode)
 		return 0;
 	if (!namespace)
 		return 0;
+ retry:
 	list_for_each(p, &namespace->list) {
 		struct vfsmount *vfsmnt = list_entry(p, struct vfsmount,
 						     mnt_list);
@@ -133,13 +138,17 @@ int ccs_may_mount(struct PATH_or_NAMEIDATA *path)
 		/***** CRITICAL SECTION START *****/
 		ccs_realpath_lock();
 		if (IS_ROOT(dentry) || !d_unhashed(dentry))
-			flag = check_conceal_mount(path, vfsmnt, dentry);
+			flag = ccs_check_conceal_mount(path, vfsmnt, dentry);
 		ccs_realpath_unlock();
 		/***** CRITICAL SECTION END *****/
 		if (flag)
 			break;
 	}
-	if (flag)
-		return print_error(path, mode);
+	if (flag) {
+		int error = ccs_print_error(&r, path);
+		if (error == 1)
+			goto retry;
+		return error;
+	}
 	return 0;
 }
